/*
 * Copyright (c) 2018 Meltytech, LLC
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtQuick.Controls 1.1
import QtQuick.Layouts 1.1
import Shotcut.Controls 1.0

Item {
    
    property string ithresh: '0'
    property string iupscale: '1'
    property string iredscale: '2'
    
    property double ithreshDefault: 0.50
    property double iupscaleDefault: 0.00
	property double iredscaleDefault: 0.00
	
	property real maxFilterPercent: 100.00
    property real maxUserPercent: 100.00
    property real defaultValue: 2.5 / maxFilterPercent
    
    property var defaultParameters: [ithresh, iupscale, iredscale]
    
    width: 250
    height: 100
    
    Component.onCompleted: {
        if (filter.isNew) {
            filter.set(ithresh, ithreshDefault)
            filter.set(iupscale, iupscaleDefault)
            filter.set(iredscale, iredscaleDefault)
            
            filter.savePreset(preset.defaultParameters)
        }
        ithreshSlider.value = filter.getDouble(ithresh) * maxFilterPercent
        iupscaleSlider.value = filter.getDouble(iupscale) * maxFilterPercent
        iredscaleSlider.value = filter.getDouble(iredscale) * maxFilterPercent
    }

    function setControls() {
        ithreshSlider.value = filter.getDouble(ithresh) * maxFilterPercent
        iupscaleSlider.value = filter.getDouble(iupscale) * maxFilterPercent
        iredscaleSlider.value = filter.getDouble(iredscale) * maxFilterPercent
    }

    GridLayout {
        anchors.fill: parent
        anchors.margins: 8
        columns: 3

        Label {
            text: qsTr('Preset')
            Layout.alignment: Qt.AlignRight
        }
        Preset {
            id: preset
            parameters: [ithresh, iupscale, iredscale]
            Layout.columnSpan: 2
            onPresetSelected: setControls()
        }

        Label {
            text: qsTr('Edge Glow Threshold')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: ithreshSlider
            minimumValue: 0.00
            maximumValue: maxUserPercent
			stepSize: 0.01
            decimals: 2
			suffix: ' %'
            //value: filter.getDouble(ithresh)
            onValueChanged: filter.set(ithresh, value / maxFilterPercent)
        }
        UndoButton {
            onClicked: ithreshSlider.value = ithreshDefault * maxFilterPercent
        }
        
        Label {
            text: qsTr('Edge Brightness')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: iupscaleSlider
            minimumValue: 0.00
            maximumValue: maxUserPercent
			stepSize: 0.01
            decimals: 2
			suffix: ' %'
            //value: filter.getDouble(ithresh)
            onValueChanged: filter.set(iupscale, value / maxFilterPercent)
        }
        UndoButton {
            onClicked: iupscaleSlider.value = iupscaleDefault * maxFilterPercent
        }


        Label {
            text: qsTr('Background Darkness')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: iredscaleSlider
            minimumValue: 0.00
            maximumValue: maxUserPercent
			stepSize: 0.01
            decimals: 2
			suffix: ' %'
            //value: filter.getDouble(iredscale)
            onValueChanged: filter.set(iredscale, value / maxFilterPercent)
            }
        UndoButton {
            onClicked: iredscaleSlider.value = iredscaleDefault * maxFilterPercent
        }

        Item {
            Layout.fillHeight: true;
        }
    }
    // Connections {
       // target: producer
      //  onPositionChanged: setControls()
    // }
  }